import React, { useEffect, useState, useRef } from "react";
import { Link as Connectedlink, useNavigate } from "react-router-dom";

import data from "../__stubs__/characters.json";
import logo from "../assets/logo_1x.png";
import logo2x from "../assets/logo_2x.png";
import logo4x from "../assets/logo_4x.png";
import { NavPanel } from "../components/nav-panel";
import { Header1 } from "../components/common";
import { InputField } from "../components/field/field";
import { URLs } from "../__data__/urls";

import {
  BrandText,
  CharName,
  CharacterItem,
  CharacterList,
  Logo,
  Main,
  MainCardWrapper,
  PageHeader,
  SearchButton,
  SearchForm,
} from "./style";

export const SearchCharacterPage = () => {
  const [searchValue, setSearchValue] = useState("");
  const [searchValueError, setSearchValueError] = useState(false);
  const searchInputRef = useRef<any>();
  const nav = useNavigate()

  useEffect(() => {
    searchInputRef.current.focus();
  }, []);

  useEffect(() => {
    if (/\d/.test(searchValue)) {
      setSearchValueError(true)
    } else {
      setSearchValueError(false)
    }
  }, [searchValue])

  const handleSearchChange = (e) => {
    const value = e.currentTarget.value;
    setSearchValue(value);
  };

  const handleSubmitSearchFrom = (event) => {
    event.preventDefault();

    fetch(`${URLs.api.main}/search`, {
      method: 'POST',
      body: JSON.stringify({
        search: searchValue
      }),
      headers: {
        'Content-Type': 'application/json'
      }
    })
    .then((response) => response.json())
    .then((data) => {
      const isAlive = data.data[0].status === "alive";

      if (isAlive) {
        nav(URLs.baseUrl)
      } else {
        nav(URLs.ui.charDetail.getUrl(data.data[0].id))
      }
    })
  }

  return (
    <>
      <PageHeader>
        <Logo
          height="44px"
          width="227"
          src={logo4x}
          alt="Логотип. Надпись Рик и Морти"
          srcSet={`
            ${logo} 220w,
            ${logo2x} 445w,
            ${logo4x} 880w,
          `}
          sizes="
          (max-width: 240px) 100px,
          (min-width: 320px) 440px,
          (min-width: 520px) 880px
        "
        />
        <NavPanel currentNavElement="Персонажи" />
      </PageHeader>
      <Main>
        <MainCardWrapper style={{ flexDirection: "column" }}>
          <Header1>
            <BrandText>Поиск</BrandText> персонажей
          </Header1>
          <SearchForm onSubmit={handleSubmitSearchFrom}>
            <InputField
              inputRef={searchInputRef}
              onChange={handleSearchChange}
              value={searchValue}
              label="Поиск"
              placeHolder="Напишите имя для поиска"
            />
            {searchValueError && <span style={{ color: 'red', display: 'flex'}}>Ай яй</span>}
            <SearchButton type="submit">Поиск</SearchButton>
          </SearchForm>
        </MainCardWrapper>
        <CharacterList>
          {data?.map((char) => (
            <Connectedlink to={URLs.ui.charDetail.getUrl(char.id)}>
              <CharacterItem key={char.id}>
                <img src={char.image} />
                <CharName>{char.name}</CharName>
              </CharacterItem>
            </Connectedlink>
          ))}
        </CharacterList>
      </Main>
    </>
  );
};
